<?php

namespace Drupal\page_not_found_files_reports\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Returns responses for Page Not Found files routes.
 */
class FilesLogController extends ControllerBase {

  /**
   * Shows the 404 log messages for all file types.
   *
   * @return array
   *   A build array in the format expected by
   *   \Drupal\Core\Render\RendererInterface::render().
   */
  public function filesLog() {
    $header = [
      ['data' => $this->t('File URL'), 'field' => 'message']
    ];
    $host = \Drupal::request()->getSchemeAndHttpHost();
    // sitemap url or sitemap file
    $sitemap = $host.'/sitemap.xml';

    // get sitemap content
    $content = file_get_contents($sitemap);

    // parse the sitemap content to object
    $xml = simplexml_load_string($content);

    // retrieve properties from the sitemap object
    $urlElement = $xml->url;

    $rows = [];
    foreach ($xml->url as $urlElement) {
      // get properties
      // store URL in php variable
      $fetchurl = $urlElement->loc;

      // get URL content using file_get_contents function and store content in php variable
      $urlContent = file_get_contents($fetchurl);

      $dom = new \DOMDocument();
      @$dom->loadHTML($urlContent);
      $xpath = new \DOMXPath($dom);
      $imgs = $xpath->evaluate("/html/body//img");

      for($i = 0; $i < $imgs->length; $i++){
        $img = $imgs->item($i);
        $src = $img->getAttribute('src');
        
        // sanitize the extracted url inside loop
        $url = filter_var($src, FILTER_SANITIZE_URL);
        if(filter_var($url, FILTER_VALIDATE_URL) === false){

          $url = $host.$url;
        }
        // Use get_headers() function
        $headers = @get_headers($url);
        if(!($headers && strpos( $headers[0], '200'))) {
          //$url." URL not Exist";
          $rows[] = [$url];
        }
  
      }
    }

    $build['dblog_top_table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => $this->t('No logs available.')
    ];
    $build['dblog_top_pager'] = ['#type' => 'pager'];

    return $build;
  }

}
